==> download.php?FileName=terralib-5.2.1.zip: packages/linux/deb-gdal.sh <==
#!/bin/bash
#
#  Copyright (C) 2008-2014 National Institute For Space Research (INPE) - Brazil.
#
#  This file is part of the TerraLib - a Framework for building GIS enabled applications.
#
#  TerraLib is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published by
#  the Free Software Foundation, either version 3 of the License,
#  or (at your option) any later version.
#
#  TerraLib is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with TerraLib. See COPYING. If not, write to
#  TerraLib Team at <terralib-team@terralib.org>.
#
#  Description: Gdal Package for Linux Ubuntu environment.
#
#  Before start, please read the "PACKAGE-INSTRUCTIONS".
#

#
# Set package info:
#
DEBNAME=terralib-gdal
DEBVERSION=2.1.3
DEBARC=amd64
LIBNAME=Gdal
FILENAME=gdal-${DEBVERSION}.tar.gz
FOLDERNAME=gdal-${DEBVERSION}
if [ -z "$OUTPUT_PATH" ]; then
  OUTPUT_PATH=`pwd`/../../../3rdparty
fi
if [ -z "$TE_VERSION" ]; then
  TE_VERSION=5.2.1
fi
#
# Check if the package already exist in the "OUTPUT_PATH":
#
if [ ! -f "${OUTPUT_PATH}/packages/${DEBNAME}_${DEBVERSION}_${DEBARC}.deb" ]; then
#
# Unpack source:
#
if [ ! -d "${FOLDERNAME}" ]; then
    tar xzvf ${FILENAME}
fi
#
# Create debian folder:
#
cd ${FOLDERNAME}
rm -rf debian
mkdir -p debian
#
# Create the copyright file:
#
cat > debian/copyright <<EOF
Format: http://www.debian.org/doc/packaging-manuals/copyright-format/1.0/
Upstream-Name: TerraLib ${LIBNAME} Library
Upstream-Contact: TerraLib Team <terralib-team@terralib.org>
Source: https://gitlab.dpi.inpe.br/terralib/terralib

Files: *
Copyright: Copyright (C) 2008 National Institute For Space Research (INPE) - Brazil
License: LGPL-3.0
  TerraLib is free software, you can redistribute it and/or modify
  it under the terms of the GNU Lesser General Public License as published by
  the Free Software Foundation, either version 3 of the License, or 
  (at your option) any later version.

  TerraLib is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  GNU Lesser General Public License for more details.

  You should have received a copy of the GNU General Public License  
  along with this program. If not, write to TerraLib Team at <terralib-team@terralib.org>.
EOF
#
# Create the changelog (no messages needed):
#
dch --create -v $DEBVERSION --distribution unstable --package ${DEBNAME} ""
#
# Create control file:
#
cat > debian/control <<EOF
Source: ${DEBNAME}
Maintainer: TerraLib Team <terralib-team@terralib.org>
Section: misc
Priority: optional
Standards-Version: 3.9.2
Build-Depends: debhelper (>= 7)

Package: ${DEBNAME}
Architecture: ${DEBARC}
Depends: \${shlibs:Depends}, \${misc:Depends}, ${DEBNAME} (= ${DEBVERSION})
Description: TerraLib ${LIBNAME} Library, version ${DEBVERSION}
Replaces:${DEBNAME} (>= 2.0.1)
EOF
#
# Create rules file:
#
cat > debian/rules <<EOF 
#!/usr/bin/make -f
%:
	dh \$@
override_dh_auto_configure:
	mkdir -p debian/${DEBNAME}/opt/terralib/$TE_VERSION/3rdparty/gdal2
	CPPFLAGS="-I/usr/include -I/usr/include/libxml2" LDFLAGS="-L/usr/lib -Wl,-rpath,/usr/lib" ./configure --prefix=`pwd`/debian/${DEBNAME}/opt/terralib/$TE_VERSION/3rdparty/gdal2 --with-pg --with-png --with-libtiff --with-geotiff --with-jpeg --with-gif --with-ecw=yes --with-xerces --with-expat=yes --with-curl --with-sqlite3 --with-geos --with-threads --with-spatialite --with-freexl --without-python --with-xml2 --with-libkml --with-hdf4 --without-netcdfd
override_dh_auto_build:
	PREFIX=`pwd`/debian/${DEBNAME}/opt/terralib/$TE_VERSION/3rdparty/gdal2 make -j 4 -s
override_dh_auto_test:
override_dh_auto_install:
	PREFIX=`pwd`/debian/${DEBNAME}/opt/terralib/$TE_VERSION/3rdparty/gdal2 make install -j 4
EOF
#
# Create some misc files:
#
echo "8" > debian/compat
mkdir -p debian/source
echo "3.0 (quilt)" > debian/source/format
#
# Configure Gdal 2:
#
CPPFLAGS="-I/usr/include -I/usr/include/libxml2" LDFLAGS="-L/usr/lib -Wl,-rpath,/usr/lib" ./configure --prefix=`pwd`/debian/${DEBNAME}/opt/terralib/$TE_VERSION/3rdparty/gdal2 --with-pg --with-png --with-libtiff --with-geotiff --with-jpeg --with-gif --with-ecw=yes --with-xerces --with-expat=yes --with-curl --with-sqlite3 --with-geos --with-threads --with-spatialite --with-freexl --without-python --with-xml2 --with-libkml --with-hdf4 --without-netcdfd
#
# Build the package:
#
# To add a GnuPG key just uncomment the "-k" and change the following key.
nice -n19 ionice -c3 debuild -us -uc -b #-kFBC36213
#
# Clean debian-package directory:
#
if [ ! -f "${DEBNAME}_${DEBVERSION}_${DEBARC}.deb" ]; then
  cd ..
  rm -rf ${FOLDERNAME}
  mkdir -p ${OUTPUT_PATH}/packages ${OUTPUT_PATH}/build-changes
  mv ${DEBNAME}_${DEBVERSION}_${DEBARC}.deb ${OUTPUT_PATH}/packages
  mv ${DEBNAME}_${DEBVERSION}_${DEBARC}.changes ${OUTPUT_PATH}/build-changes
  mv ${DEBNAME}_${DEBVERSION}_${DEBARC}.build ${OUTPUT_PATH}/build-changes
fi
fi

==> download.php?FileName=terralib-5.3.2.zip: packages/linux/deb-gdal.sh <==
#!/bin/bash
#
#  Copyright (C) 2008-2014 National Institute For Space Research (INPE) - Brazil.
#
#  This file is part of the TerraLib - a Framework for building GIS enabled applications.
#
#  TerraLib is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published by
#  the Free Software Foundation, either version 3 of the License,
#  or (at your option) any later version.
#
#  TerraLib is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with TerraLib. See COPYING. If not, write to
#  TerraLib Team at <terralib-team@terralib.org>.
#
#  Description: Gdal Package for Linux Ubuntu environment.
#
#  Before start, please read the "PACKAGE-INSTRUCTIONS".
#

#
# Set package info:
#
DEBNAME=terralib-gdal
DEBVERSION=2.1.3
DEBARC=amd64
LIBNAME=Gdal
FILENAME=gdal-${DEBVERSION}.tar.gz
FOLDERNAME=gdal-${DEBVERSION}
if [ -z "$OUTPUT_PATH" ]; then
  OUTPUT_PATH=`pwd`/../../../3rdparty
fi

#
# Check if the package already exist in the "OUTPUT_PATH":
#
if [ ! -f "${OUTPUT_PATH}/packages/${DEBNAME}_${DEBVERSION}_${DEBARC}.deb" ]; then
#
# Unpack source:
#
if [ ! -d "${FOLDERNAME}" ]; then
    tar xzvf ${FILENAME}
fi
#
# Create debian folder:
#
cd ${FOLDERNAME}
rm -rf debian
mkdir -p debian
#
# Create the copyright file:
#
cat > debian/copyright <<EOF
Format: http://www.debian.org/doc/packaging-manuals/copyright-format/1.0/
Upstream-Name: TerraLib ${LIBNAME} Library
Upstream-Contact: TerraLib Team <terralib-team@terralib.org>
Source: https://gitlab.dpi.inpe.br/terralib/terralib

Files: *
Copyright: Copyright (C) 2008 National Institute For Space Research (INPE) - Brazil
License: LGPL-3.0
  TerraLib is free software, you can redistribute it and/or modify
  it under the terms of the GNU Lesser General Public License as published by
  the Free Software Foundation, either version 3 of the License, or 
  (at your option) any later version.

  TerraLib is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  GNU Lesser General Public License for more details.

  You should have received a copy of the GNU General Public License  
  along with this program. If not, write to TerraLib Team at <terralib-team@terralib.org>.
EOF
#
# Create the changelog (no messages needed):
#
dch --create -v $DEBVERSION --distribution unstable --package ${DEBNAME} ""
#
# Create control file:
#
cat > debian/control <<EOF
Source: ${DEBNAME}
Maintainer: TerraLib Team <terralib-team@terralib.org>
Section: misc
Priority: optional
Standards-Version: 3.9.2
Build-Depends: debhelper (>= 7)

Package: ${DEBNAME}
Architecture: ${DEBARC}
Depends: \${shlibs:Depends}, \${misc:Depends}, ${DEBNAME} (= ${DEBVERSION})
Description: TerraLib ${LIBNAME} Library, version ${DEBVERSION}
Replaces:${DEBNAME} (>= 2.0.1)
EOF
#
# Create rules file:
#
cat > debian/rules <<EOF 
#!/usr/bin/make -f
%:
	dh \$@
override_dh_auto_configure:
	mkdir -p debian/${DEBNAME}/opt/terralib/$TE_VERSION/3rdparty
	CPPFLAGS="-I/usr/include -I/usr/include/libxml2" LDFLAGS="-L/usr/lib -Wl,-rpath,/usr/lib" ./configure --prefix=`pwd`/debian/${DEBNAME}/opt/terralib/$TE_VERSION/3rdparty --with-pg --with-png --with-libtiff --with-geotiff --with-jpeg --with-gif --with-ecw=yes --with-xerces --with-expat=yes --with-curl --with-sqlite3 --with-geos --with-threads --with-spatialite --with-freexl --without-python --with-xml2 --with-libkml --with-hdf4 --without-netcdfd
override_dh_auto_build:
	PREFIX=`pwd`/debian/${DEBNAME}/opt/terralib/$TE_VERSION/3rdparty make -j 4 -s
override_dh_auto_test:
override_dh_auto_install:
	PREFIX=`pwd`/debian/${DEBNAME}/opt/terralib/$TE_VERSION/3rdparty make install -j 4
EOF
#
# Create some misc files:
#
echo "8" > debian/compat
mkdir -p debian/source
echo "3.0 (quilt)" > debian/source/format
#
# Configure Gdal 2:
#
CPPFLAGS="-I/usr/include -I/usr/include/libxml2" LDFLAGS="-L/usr/lib -Wl,-rpath,/usr/lib" ./configure --prefix=`pwd`/debian/${DEBNAME}/opt/terralib/$TE_VERSION/3rdparty --with-pg --with-png --with-libtiff --with-geotiff --with-jpeg --with-gif --with-ecw=yes --with-xerces --with-expat=yes --with-curl --with-sqlite3 --with-geos --with-threads --with-spatialite --with-freexl --without-python --with-xml2 --with-libkml --with-hdf4 --without-netcdfd
#
# Build the package:
#
# To add a GnuPG key just uncomment the "-k" and change the following key.
nice -n19 ionice -c3 debuild -us -uc -b #-kFBC36213
#
# Clean debian-package directory:
#
if [ ! -f "${DEBNAME}_${DEBVERSION}_${DEBARC}.deb" ]; then
  cd ..
  rm -rf ${FOLDERNAME}
  mkdir -p ${OUTPUT_PATH}/packages ${OUTPUT_PATH}/build-changes
  mv ${DEBNAME}_${DEBVERSION}_${DEBARC}.deb ${OUTPUT_PATH}/packages
  mv ${DEBNAME}_${DEBVERSION}_${DEBARC}.changes ${OUTPUT_PATH}/build-changes
  mv ${DEBNAME}_${DEBVERSION}_${DEBARC}.build ${OUTPUT_PATH}/build-changes
fi
fi
